pub struct WindUV<S> {
pub u: S,
pub v: S,
}Expand description
Wind in U and V components in m/s.
Fields
u: Sv: STrait Implementations
Sourceimpl<T, S> AddAssign<T> for WindUV<S>
impl<T, S> AddAssign<T> for WindUV<S>
Sourcefn add_assign(&mut self, rhs: T)
fn add_assign(&mut self, rhs: T)
Performs the
+= operation. Read moreSourceimpl<S1, S2> From<WindSpdDir<S1>> for WindUV<S2>
impl<S1, S2> From<WindSpdDir<S1>> for WindUV<S2>
Sourcefn from(wind: WindSpdDir<S1>) -> Self
fn from(wind: WindSpdDir<S1>) -> Self
Converts to this type from the input type.
Sourceimpl<S1, S2> From<WindUV<S1>> for WindSpdDir<S2>
impl<S1, S2> From<WindUV<S1>> for WindSpdDir<S2>
Sourceimpl<T, S> SubAssign<T> for WindUV<S>
impl<T, S> SubAssign<T> for WindUV<S>
Sourcefn sub_assign(&mut self, rhs: T)
fn sub_assign(&mut self, rhs: T)
Performs the
-= operation. Read moreSourceimpl<S> VectorQuantity<S> for WindUV<S>where
S: Quantity,
impl<S> VectorQuantity<S> for WindUV<S>where
S: Quantity,
Sourcefn pack_xy(vals: (S, S)) -> Self
fn pack_xy(vals: (S, S)) -> Self
Create a new instance of self by wrapping some values. This must be x-y coordinates from the
standard cartesian coordinate system.
Sourcefn unpack_xy(self) -> (S, S)
fn unpack_xy(self) -> (S, S)
Unpack a wrapped value without any error checking. The returned values represent the vector
in a standard x-y cartesian coordinate system.
Sourcefn unwrap_xy(self) -> (S, S)
fn unwrap_xy(self) -> (S, S)
Unwrap the values from the new type and check validity, panic if contents are invalid. The
returned values represent the vector in a standard x-y cartesian coordinate system.
Sourcefn into_option(self) -> Option<(S, S)>
fn into_option(self) -> Option<(S, S)>
Convert into an option that is
None if the content is invalid. The returned values
represent the vector in a standard x-y cartesian coordinate system.impl<S: Copy> Copy for WindUV<S>
impl<S: Speed> Wind<S> for WindUV<S>